#BCG

library(car)
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetB <- read_excel("dsetB.xlsx")
summary(dsetB)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15  + Psingle15 + PWork15 + Checkup3mth + Foreigners + NurseryRate + SoMigration 
           +IncomePer + City_Village + Workers + MassVac + Pediatrics, data =  dsetB) 

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)


#ANOVA nullmodel
anovamodel <- lmer(rate ~  (1|ken), data = dsetB, REML = FALSE)

#random effects ICC = (ken/Residual + ken = 0.07282267)


#CWC 
dsetB$Psingle15.m <-ave(dsetB$Psingle15, dsetB$ken)
dsetB$Checkup3mth.m <-ave(dsetB$Checkup3mth, dsetB$ken)
dsetB$SoMigration.m <-ave(dsetB$SoMigration, dsetB$ken)
dsetB$IncomePer.m <- ave(dsetB$IncomePer, dsetB$ken)
dsetB$MassVac.m <-ave(dsetB$MassVac, dsetB$ken)


dsetB$Psingle15.cwc <- dsetB$Psingle15 - dsetB$Psingle15.m
dsetB$Checkup3mth.cwc <- dsetB$Checkup3mth - dsetB$Checkup3mth.m
dsetB$SoMigration.cwc <- dsetB$SoMigration - dsetB$SoMigration.m
dsetB$IncomePer.cwc <- dsetB$IncomePer - dsetB$IncomePer.m
dsetB$MassVac.cwc <- dsetB$MassVac - dsetB$MassVac.m


#mdev
Psingle15.mdev <- dsetB$Psingle15.m - mean(dsetB$Psingle15.m)
Checkup3mth.mdev <- dsetB$Checkup3mth.m - mean(dsetB$Checkup3mth.m)
SoMigration.mdev <- dsetB$SoMigration.m - mean(dsetB$SoMigration.m)
IncomePer.mdev <- dsetB$IncomePer.m - mean(dsetB$IncomePer.m)
MassVac.mdev <- dsetB$MassVac.m - mean(dsetB$MassVac.m)


#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  Psingle15.cwc + Checkup3mth.cwc + SoMigration.cwc + IncomePer.cwc + MassVac.cwc 
                      + Psingle15.mdev + Checkup3mth.mdev + SoMigration.mdev + IncomePer.mdev + MassVac.mdev 
                      + (1|dsetB$ken), data = dsetB, REML = FALSE)

confint(bwefffctmodel, level = 0.95)

library(car)
vif(bwefffctmodel)

bwefffctmodel2 <- lmer(rate ~  Psingle15.cwc + Checkup3mth.cwc + SoMigration.cwc + IncomePer.cwc + MassVac.cwc 
                       + Psingle15.mdev + Checkup3mth.mdev + SoMigration.mdev  + MassVac.mdev 
                       + (1|dsetB$ken), data = dsetB, REML = FALSE)


#検定
options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(88,98), ylim = c(-30,30))
plot(predict(mrg2), residuals(mrg2),xlim = c(88,98), ylim = c(-30,30))


residuals(mrg2)


#都道府県ごとの予測値
plot(dsetB$ken, predict(bwefffctmodel))
plot(dsetB$ken, predict(mrg2))

#都道府県ごとの残差
plot(dsetB$ken, residuals(bwefffctmodel), ylim = c(-20, 20))
plot(dsetB$ken, residuals(mrg2), ylim = c(-20, 20))

library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetB$rate ~ dsetB$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(scale(dsetB$rate)), col = "red3", lwd = 2)


result.B <- data.frame(dsetB$number,dsetB$name, dsetB$ken,dsetB$rate,residuals(mrg2), 
                       residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.B, file="C:/Users/Yuki/Documents/R/Mthesis/result.B.csv", sep=",")


