#DPT1

library(readxl)
library(MuMIn)
options(na.action = "na.fail")
library(lmerTest)

dsetD1 <- read_excel("dsetD1.xlsx")
summary(dsetD1)


mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetD1)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetD1, REML = FALSE)
summary(anovamodel)


#model4
#CWC 
dsetD1$MotherYear.m <-ave(dsetD1$MotherYear, dsetD1$ken)
dsetD1$Chi_Fam15.m <-ave(dsetD1$Chi_Fam15, dsetD1$ken)
dsetD1$Psingle15.m <-ave(dsetD1$Psingle15, dsetD1$ken)
dsetD1$PWork15.m <-ave(dsetD1$PWork15, dsetD1$ken)
dsetD1$Checkup3mth.m <-ave(dsetD1$Checkup3mth, dsetD1$ken)
dsetD1$IncomePer.m <-ave(dsetD1$IncomePer, dsetD1$ken)
dsetD1$City_Village.m <-ave(dsetD1$City_Village, dsetD1$ken)
dsetD1$Pediatrics.m <-ave(dsetD1$Pediatrics, dsetD1$ken)

dsetD1$MotherYear.cwc <- dsetD1$MotherYear - dsetD1$MotherYear.m
dsetD1$Chi_Fam15.cwc <- dsetD1$Chi_Fam15 - dsetD1$Chi_Fam15.m
dsetD1$Psingle15.cwc <- dsetD1$Psingle15 - dsetD1$Psingle15.m
dsetD1$PWork15.cwc <- dsetD1$PWork15 - dsetD1$PWork15.m
dsetD1$Checkup3mth.cwc <- dsetD1$Checkup3mth - dsetD1$Checkup3mth.m
dsetD1$IncomePer.cwc <- dsetD1$IncomePer - dsetD1$IncomePer.m
dsetD1$City_Village.cwc <- dsetD1$City_Village - dsetD1$City_Village.m
dsetD1$Pediatrics.cwc <- dsetD1$Pediatrics - dsetD1$Pediatrics.m


#mdev
MotherYear.mdev <- dsetD1$MotherYear.m - mean(dsetD1$MotherYear.m)
Chi_Fam15.mdev <- dsetD1$Chi_Fam15.m - mean(dsetD1$Chi_Fam15.m)
Psingle15.mdev <- dsetD1$Psingle15.m - mean(dsetD1$Psingle15.m)
PWork15.mdev <- dsetD1$PWork15.m - mean(dsetD1$PWork15.m)
Checkup3mth.mdev <- dsetD1$Checkup3mth.m - mean(dsetD1$Checkup3mth.m)
IncomePer.mdev <- dsetD1$IncomePer.m - mean(dsetD1$IncomePer.m)
City_Village.mdev <- dsetD1$City_Village.m - mean(dsetD1$City_Village.m)
Pediatrics.mdev <- dsetD1$Pediatrics.m - mean(dsetD1$Pediatrics.m)


#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  MotherYear.cwc + Chi_Fam15.cwc  +Psingle15.cwc +PWork15.cwc + Checkup3mth.cwc + IncomePer.cwc + City_Village.cwc + Pediatrics.cwc
                        + MotherYear.mdev + Chi_Fam15.mdev+ Psingle15.mdev + PWork15.mdev + Checkup3mth.mdev + IncomePer.mdev + City_Village.mdev + Pediatrics.mdev
                      + (1|ken), data = dsetD1, REML = FALSE)

#vif>10 -IncomePer.mdev
bwefffctmodel2 <- lmer(rate ~  MotherYear.cwc + Chi_Fam15.cwc  +Psingle15.cwc +PWork15.cwc + Checkup3mth.cwc + IncomePer.cwc + City_Village.cwc + Pediatrics.cwc
                      + MotherYear.mdev + Chi_Fam15.mdev+ Psingle15.mdev + PWork15.mdev + Checkup3mth.mdev  + City_Village.mdev + Pediatrics.mdev
                      + (1|ken), data = dsetD1, REML = FALSE)


summary(bwefffctmodel2)


#検定
options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
confint(bwefffctmodel, level = 0.95)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)

library(car)
vif(bwefffctmodel)

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))


#箱ひげ図

library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetD1$rate ~ dsetD1$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetD1$rate), col = "red3", lwd = 2)


result.D1 <- data.frame(dsetD1$number,dsetD1$name, dsetD1$ken,dsetD1$rate,
                        residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.D1, file="C:/Users/Yuki/Documents/R/Mthesis/result.D1.csv", sep=",")


