#DPT2

library(readxl)

library(lmerTest)

library(MuMIn)
options(na.action = "na.fail")

dsetD2 <- read_excel("dsetD2.xlsx")

summary(dsetD2)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetD2)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)

#ANCOVA nullmodel model3
anovamodel <- lmer(rate ~  (1|ken), data = dsetD2, REML = FALSE)
summary(anovamodel)
#random effects ICC = (ken/Residual + ken = 0.06075522)

#model4bweffectmodel

#CWC 
dsetD2$Chi_Fam15.m <-ave(dsetD2$Chi_Fam15, dsetD2$ken)
dsetD2$Psingle15.m <-ave(dsetD2$Psingle15, dsetD2$ken)
dsetD2$Checkup3mth.m <-ave(dsetD2$Checkup3mth, dsetD2$ken)
dsetD2$IncomePer.m <-ave(dsetD2$IncomePer, dsetD2$ken)

dsetD2$Chi_Fam15.cwc <- dsetD2$Chi_Fam15 - dsetD2$Chi_Fam15.m
dsetD2$Psingle15.cwc <- dsetD2$Psingle15 - dsetD2$Psingle15.m
dsetD2$Checkup3mth.cwc <- dsetD2$Checkup3mth - dsetD2$Checkup3mth.m
dsetD2$IncomePer.cwc <- dsetD2$IncomePer - dsetD2$IncomePer.m

#Mdev
Chi_Fam15.mdev <- dsetD2$Chi_Fam15.m - mean(dsetD2$Chi_Fam15.m)
Psingle15.mdev <- dsetD2$Psingle15.m - mean(dsetD2$Psingle15.m)
Checkup3mth.mdev <- dsetD2$Checkup3mth.m - mean(dsetD2$Checkup3mth.m)
IncomePer.mdev <- dsetD2$IncomePer.m - mean(dsetD2$IncomePer.m)



#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  Chi_Fam15.cwc + Psingle15.cwc + Checkup3mth.cwc + IncomePer.cwc
                      + Chi_Fam15.mdev + Psingle15.mdev + Checkup3mth.mdev +  IncomePer.mdev 
                      + (1|ken), data = dsetD2, REML = FALSE)

vif(bwefffctmodel)

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))
plot(bwefffctmodel)
plot(mrg2)


options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


#箱ひげ図

library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetD2$rate ~ dsetD2$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetD2$rate), col = "red3", lwd = 2)


result.D2 <- data.frame(dsetD2$number,dsetD2$name, dsetD2$ken,dsetD2$rate,
                        residuals(mrg2), residuals(bwefffctmodel),scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.D2, file="C:/Users/Yuki/Documents/R/Mthesis/result.D2.csv", sep=",")

