#DPT3

library(readxl)
library(lmerTest)
library(car)
library(MuMIn)
options(na.action = "na.fail")

dsetD3 <- read_excel("dsetD3.xlsx")


summary(dsetD3)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetD3)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetD3, REML = FALSE)
summary(anovamodel)
#random effects ICC = (ken/Residual + ken = 0.0666559)
#model4

#CWC 
dsetD3$Chi_Fam15.m <- ave(dsetD3$Chi_Fam15, dsetD3$ken)
dsetD3$Psingle15.m <- ave(dsetD3$Psingle15, dsetD3$ken)
dsetD3$Checkup3mth.m <- ave(dsetD3$Checkup3mth, dsetD3$ken)
dsetD3$IncomePer.m <- ave(dsetD3$IncomePer, dsetD3$ken)
dsetD3$MassVac.m <- ave(dsetD3$MassVac, dsetD3$ken)

dsetD3$Chi_Fam15.cwc <- dsetD3$Chi_Fam15 - dsetD3$Chi_Fam15.m
dsetD3$Psingle15.cwc <- dsetD3$Psingle15 - dsetD3$Psingle15.m
dsetD3$Checkup3mth.cwc <- dsetD3$Checkup3mth - dsetD3$Checkup3mth.m
dsetD3$IncomePer.cwc <- dsetD3$IncomePer - dsetD3$IncomePer.m
dsetD3$MassVac.cwc <- dsetD3$MassVac - dsetD3$MassVac.m

#mdev

Chi_Fam15.mdev <- dsetD3$Chi_Fam15.m - mean(dsetD3$Chi_Fam15.m)
Psingle15.mdev <- dsetD3$Psingle15.m - mean(dsetD3$Psingle15.m)
Checkup3mth.mdev <- dsetD3$Checkup3mth.m - mean(dsetD3$Checkup3mth.m)
IncomePer.mdev <- dsetD3$IncomePer.m - mean(dsetD3$IncomePer.m)
MassVac.mdev <- dsetD3$MassVac.m - mean(dsetD3$MassVac.m)


#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  Chi_Fam15.cwc + Psingle15.cwc + Checkup3mth.cwc  +IncomePer.cwc +  MassVac.cwc 
                      + Chi_Fam15.mdev + Psingle15.mdev + Checkup3mth.mdev + IncomePer.mdev + MassVac.mdev
                      + (1|ken), data = dsetD3, REML = FALSE)
summary(bwefffctmodel)
fixef(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")
confint(bwefffctmodel, level = .95)


#要約

options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)

#bweffectがベストモデル。

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))

#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetD3$rate ~ dsetD3$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetD3$rate), col = "red3", lwd = 2)



result.D3 <- data.frame(dsetD3$number,dsetD3$name, dsetD3$ken,dsetD3$rate,
                        residuals(mrg2), residuals(bwefffctmodel),scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.D3, file="C:/Users/Yuki/Documents/R/Mthesis/result.D3.csv", sep=",")



