#HBV1
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetHBV1 <- read_excel("dsetHBV1.xlsx")
summary(dsetHBV1)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetHBV1)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)

anovamodel <- lmer(rate ~  (1|ken), data = dsetHBV1, REML = FALSE)
summary(anovamodel)

library(ICC)
ICCest(as.factor(ken), rate, data = dsetHBV1, alpha = 0.05, CI.type = ("Smith"))
ICCest(as.factor(dsetHBV1$ken), rate, data = z, alpha = 0.05, CI.type = ("Smith")) #標準化ver.結果は同じ。

#model4

#CWC 
dsetHBV1$MotherYear.m <- ave(dsetHBV1$MotherYear, dsetHBV1$ken)
dsetHBV1$Chi_Fam15.m <- ave(dsetHBV1$Chi_Fam15, dsetHBV1$ken)
dsetHBV1$PWork15.m <- ave(dsetHBV1$PWork15, dsetHBV1$ken)
dsetHBV1$Checkup3mth.m <- ave(dsetHBV1$Checkup3mth, dsetHBV1$ken)
dsetHBV1$MassVac.m <- ave(dsetHBV1$MassVac, dsetHBV1$ken)
dsetHBV1$Pediatrics.m <- ave(dsetHBV1$Pediatrics, dsetHBV1$ken)


dsetHBV1$MotherYear.cwc <- dsetHBV1$MotherYear - dsetHBV1$MotherYear.m
dsetHBV1$Chi_Fam15.cwc <- dsetHBV1$Chi_Fam15 - dsetHBV1$Chi_Fam15.m
dsetHBV1$PWork15.cwc <- dsetHBV1$PWork15 - dsetHBV1$PWork15.m
dsetHBV1$Checkup3mth.cwc <- dsetHBV1$Checkup3mth - dsetHBV1$Checkup3mth.m
dsetHBV1$Pediatrics.cwc <- dsetHBV1$Pediatrics - dsetHBV1$Pediatrics.m
dsetHBV1$MassVac.cwc <- dsetHBV1$MassVac - dsetHBV1$MassVac.m


#mdev

Chi_Fam15.mdev <- dsetHBV1$Chi_Fam15.m - mean(dsetHBV1$Chi_Fam15.m)
PWork15.mdev <- dsetHBV1$PWork15.m - mean(dsetHBV1$PWork15.m)
Checkup3mth.mdev <- dsetHBV1$Checkup3mth.m - mean(dsetHBV1$Checkup3mth.m)
Pediatrics.mdev <- dsetHBV1$Pediatrics.m - mean(dsetHBV1$Pediatrics.m)
MassVac.mdev <- dsetHBV1$MassVac.m - mean(dsetHBV1$MassVac.m)
MotherYear.mdev <- dsetHBV1$MotherYear.m - mean(dsetHBV1$MotherYear.m)



bweffectmodel <- lmer(rate ~ MotherYear.cwc + Chi_Fam15.cwc + PWork15.cwc + Checkup3mth.cwc  + MassVac.cwc +Pediatrics.cwc
                      + MotherYear.mdev + Chi_Fam15.mdev + PWork15.mdev + Checkup3mth.mdev + MassVac.mdev + Pediatrics.mdev 
                      + (1|ken), data = dsetHBV1, REML = FALSE)
summary(bweffectmodel)
confint(bweffectmodel, level = .95, method = "Wald")

fixef(bweffectmodel)


#summary
options(scipen=8)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bweffectmodel)
BIC(mrg1, mrg2, anovamodel, bweffectmodel)
AIC(mrg1, mrg2, anovamodel, bweffectmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bweffectmodel)

#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetHBV1$rate ~ dsetHBV1$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetHBV1$rate), col = "red3", lwd = 2)



result.HBV1 <- data.frame(dsetHBV1$number,dsetHBV1$name, dsetHBV1$ken,dsetHBV1$rate,
                          residuals(mrg2), residuals(bweffectmodel), scale(residuals(mrg2)), scale(residuals(bweffectmodel)))


write.table(result.HBV1, file="C:/Users/Yuki/Documents/R/Mthesis/result.HBV1.csv", sep=",")

