#HBV3
library(car)
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetHBV3 <- read_excel("dsetHBV3.xlsx")
summary(dsetHBV3)

mrg1 <- lm(rate ~  MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data =  dsetHBV3)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)


confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)


#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetHBV3, REML = FALSE)
summary(anovamodel)

#model4

#CWC 
dsetHBV3$Psingle15.m <- ave(dsetHBV3$Psingle15, dsetHBV3$ken)
dsetHBV3$Chi_Fam15.m <- ave(dsetHBV3$Chi_Fam15, dsetHBV3$ken)
dsetHBV3$Checkup3mth.m <- ave(dsetHBV3$Checkup3mth, dsetHBV3$ken)
dsetHBV3$Pediatrics.m <- ave(dsetHBV3$Pediatrics, dsetHBV3$ken)

dsetHBV3$Psingle15.cwc <- dsetHBV3$Psingle15 - dsetHBV3$Psingle15.m
dsetHBV3$Chi_Fam15.cwc <- dsetHBV3$Chi_Fam15 - dsetHBV3$Chi_Fam15.m
dsetHBV3$Checkup3mth.cwc <- dsetHBV3$Checkup3mth - dsetHBV3$Checkup3mth.m
dsetHBV3$Pediatrics.cwc <- dsetHBV3$Pediatrics - dsetHBV3$Pediatrics.m

#mdev

Psingle15.mdev <- dsetHBV3$Psingle15.m - mean(dsetHBV3$Psingle15.m)
Chi_Fam15.mdev <- dsetHBV3$Chi_Fam15.m - mean(dsetHBV3$Chi_Fam15.m)
Checkup3mth.mdev <- dsetHBV3$Checkup3mth.m - mean(dsetHBV3$Checkup3mth.m)
Pediatrics.mdev <- dsetHBV3$Pediatrics.m - mean(dsetHBV3$Pediatrics.m)



#集団・個人レベル効果モデル

bweffectmodel <- lmer(rate ~  Chi_Fam15.cwc + Psingle15.cwc +  Checkup3mth.cwc+ Pediatrics.cwc
                      + Chi_Fam15.mdev + Psingle15.mdev  +  Checkup3mth.mdev  + Pediatrics.mdev
                      + (1|ken), data = dsetHBV3, REML = FALSE)

fixef(bweffectmodel)
summary(bweffectmodel)
confint(bweffectmodel, level = .95, method = "Wald")
vif(bweffectmodel)


options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bweffectmodel)
BIC(mrg1, mrg2, anovamodel, bweffectmodel)
AIC(mrg1, mrg2, anovamodel, bweffectmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bweffectmodel)

#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetHBV3$rate ~ dsetHBV3$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetHBV3$rate), col = "red3", lwd = 2)


result.HBV3 <- data.frame(dsetHBV3$number,dsetHBV3$name, dsetHBV3$ken,dsetHBV3$rate,
                          residuals(mrg2), residuals(bweffectmodel), scale(residuals(mrg2)), scale(residuals(bweffectmodel)))

write.table(result.HBV3, file="C:/Users/Yuki/Documents/R/Mthesis/result.HBV3.csv", sep=",")



