#VAR1
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetVAR1 <- read_excel("dsetVAR1.xlsx")
summary(dsetVAR1)


mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup18m + Foreigners
           + NurseryRate + SoMigration + + IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetVAR1)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)

anovamodel <- lmer(rate ~  (1|ken), data = dsetVAR1, REML = FALSE)
summary(anovamodel)

library(ICC)
ICCest(as.factor(ken), rate, data = dsetVAR1, alpha = 0.05, CI.type = ("Smith"))


library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetVAR1$rate ~ dsetVAR1$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetVAR1$rate), col = "red3", lwd = 2)

confint(mrg2, level = .95, method = "Wald")

#検定
options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
BIC(mrg1, mrg2, anovamodel)
AIC(mrg1, mrg2, anovamodel)
r.squaredGLMM(anovamodel)

result.VAR1 <- data.frame(dsetVAR1$number,dsetVAR1$name, dsetVAR1$ken,dsetVAR1$rate,
                          residuals(mrg2), scale(residuals(mrg2)))


write.table(result.VAR1, file="C:/Users/Yuki/Documents/R/Mthesis/result.VAR1.csv", sep=",")
