#VAR2
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetVAR2 <- read_excel("dsetVAR2.xlsx")
summary(dsetVAR2)

mrg1 <- lm(rate ~MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup18m + Foreigners
           + NurseryRate + SoMigration + + IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetVAR2)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)




#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetVAR2, REML = FALSE)
summary(anovamodel)

#model4

#CWC 
dsetVAR2$MotherYear.m <- ave(dsetVAR2$MotherYear, dsetVAR2$ken)
dsetVAR2$Psingle15.m <- ave(dsetVAR2$Psingle15, dsetVAR2$ken)
dsetVAR2$PWork15.m <- ave(dsetVAR2$PWork15, dsetVAR2$ken)
dsetVAR2$Checkup18m.m <- ave(dsetVAR2$Checkup18m, dsetVAR2$ken)
dsetVAR2$NurseryRate.m <- ave(dsetVAR2$NurseryRate, dsetVAR2$ken)
dsetVAR2$SoMigration.m <-ave(dsetVAR2$SoMigration, dsetVAR2$ken)
dsetVAR2$City_Village.m <-ave(dsetVAR2$City_Village, dsetVAR2$ken)
dsetVAR2$Workers.m <- ave(dsetVAR2$Workers, dsetVAR2$ken)
dsetVAR2$MassVac.m <- ave(dsetVAR2$MassVac, dsetVAR2$ken)
dsetVAR2$Foreigners.m <- ave(dsetVAR2$Foreigners, dsetVAR2$ken)


dsetVAR2$Checkup18m.cwc <- dsetVAR2$Checkup18m - dsetVAR2$Checkup18m.m
dsetVAR2$Psingle15.cwc <- dsetVAR2$Psingle15 - dsetVAR2$Psingle15.m
dsetVAR2$PWork15.cwc <- dsetVAR2$PWork15 - dsetVAR2$PWork15.m
dsetVAR2$NurseryRate.cwc <- dsetVAR2$NurseryRate - dsetVAR2$NurseryRate.m
dsetVAR2$Workers.cwc <- dsetVAR2$Workers - dsetVAR2$Workers.m
dsetVAR2$MassVac.cwc <- dsetVAR2$MassVac - dsetVAR2$MassVac.m
dsetVAR2$MotherYear.cwc <- dsetVAR2$MotherYear - dsetVAR2$MotherYear.m
dsetVAR2$SoMigration.cwc <- dsetVAR2$SoMigration - dsetVAR2$SoMigration.m
dsetVAR2$City_Village.cwc <- dsetVAR2$City_Village - dsetVAR2$City_Village.m
dsetVAR2$Foreigners.cwc <- dsetVAR2$Foreigners - dsetVAR2$Foreigners.m


#mdev

Psingle15.mdev <- dsetVAR2$Psingle15.m - mean(dsetVAR2$Psingle15.m)
PWork15.mdev <- dsetVAR2$PWork15.m - mean(dsetVAR2$PWork15.m)
Checkup18m.mdev <- dsetVAR2$Checkup18m.m - mean(dsetVAR2$Checkup18m.m)
NurseryRate.mdev <- dsetVAR2$NurseryRate.m - mean(dsetVAR2$NurseryRate.m)
MassVac.mdev <- dsetVAR2$MassVac.m - mean(dsetVAR2$MassVac.m)
Workers.mdev <- dsetVAR2$Workers.m - mean(dsetVAR2$Workers.m)
MotherYear.mdev <- dsetVAR2$MotherYear.m - mean(dsetVAR2$MotherYear.m)
SoMigration.mdev <- dsetVAR2$SoMigration.m - mean(dsetVAR2$SoMigration.m)
City_Village.mdev <- dsetVAR2$City_Village.m - mean(dsetVAR2$City_Village.m)
Foreigners.mdev <- dsetVAR2$Foreigners.m - mean(dsetVAR2$Foreigners.m)



bweffectmodel <- lmer(rate ~  Psingle15.cwc + PWork15.cwc + Checkup18m.cwc +NurseryRate.cwc + MassVac.cwc + Workers.cwc + MotherYear.cwc + SoMigration.cwc +City_Village.cwc + Foreigners.cwc
                      + Psingle15.mdev + PWork15.mdev + Checkup18m.mdev + NurseryRate.mdev + MassVac.mdev + Workers.mdev + +MotherYear.mdev + SoMigration.mdev + City_Village.mdev + Foreigners.mdev
                      + (1|ken), data = dsetVAR2, REML = FALSE)
summary(bweffectmodel)
confint(bweffectmodel, level = .95, method = "Wald")

fixef(bweffectmodel)

#残差プロット
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))


library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetVAR2$rate ~ dsetVAR2$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetVAR2$rate), col = "red3", lwd = 2)


options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bweffectmodel)
BIC(mrg1, mrg2, anovamodel, bweffectmodel)
AIC(mrg1, mrg2, anovamodel, bweffectmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bweffectmodel)

result.VAR2 <- data.frame(dsetVAR2$number,dsetVAR2$name, dsetVAR2$ken,dsetVAR2$rate,
                          residuals(mrg2), residuals(bweffectmodel), scale(residuals(mrg2)), scale(residuals(bweffectmodel)))

write.table(result.VAR2, file="C:/Users/Yuki/Documents/R/Mthesis/result.VAR2.csv", sep=",")

