#hib1
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsethib1 <- read_excel("dsethib1.xlsx")
summary(dsethib1)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics,  data = dsethib1)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsethib1, REML = FALSE)
summary(anovamodel)
#random effects ICC = (ken/Residual + ken = 0.0666559)

#model4

#CWC 
dsethib1$MotherYear.m <- ave(dsethib1$MotherYear, dsethib1$ken)
dsethib1$Psingle15.m <- ave(dsethib1$Psingle15, dsethib1$ken)
dsethib1$Foreigners.m <- ave(dsethib1$Foreigners, dsethib1$ken)
dsethib1$SoMigration.m <- ave(dsethib1$SoMigration, dsethib1$ken)
dsethib1$IncomePer.m <- ave(dsethib1$IncomePer, dsethib1$ken)
dsethib1$City_Village.m <- ave(dsethib1$City_Village, dsethib1$ken)
dsethib1$Pediatrics.m <- ave(dsethib1$Pediatrics, dsethib1$ken)


dsethib1$MotherYear.cwc <- dsethib1$MotherYear - dsethib1$MotherYear.m
dsethib1$Psingle15.cwc <- dsethib1$Psingle15 - dsethib1$Psingle15.m
dsethib1$Foreigners.cwc <- dsethib1$Foreigners - dsethib1$Foreigners.m
dsethib1$SoMigration.cwc <- dsethib1$SoMigration - dsethib1$SoMigration.m
dsethib1$IncomePer.cwc <- dsethib1$IncomePer - dsethib1$IncomePer.m
dsethib1$City_Village.cwc <- dsethib1$City_Village - dsethib1$City_Village.m
dsethib1$Pediatrics.cwc <- dsethib1$Pediatrics - dsethib1$Pediatrics.m

#mdev
MotherYear.mdev <- dsethib1$MotherYear.m - mean(dsethib1$MotherYear.m)
Psingle15.mdev <- dsethib1$Psingle15.m - mean(dsethib1$Psingle15.m)
SoMigration.mdev <- dsethib1$SoMigration.m - mean(dsethib1$SoMigration.m)
Foreigners.mdev <- dsethib1$Foreigners.m - mean(dsethib1$Foreigners.m)
IncomePer.mdev <- dsethib1$IncomePer.m - mean(dsethib1$IncomePer.m)
City_Village.mdev <- dsethib1$City_Village.m - mean(dsethib1$City_Village.m)
Pediatrics.mdev <- dsethib1$Pediatrics.m - mean(dsethib1$Pediatrics.m)


#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  MotherYear.cwc + Psingle15.cwc  + Foreigners.cwc + SoMigration.cwc +IncomePer.cwc + City_Village.cwc + Pediatrics.cwc
                      +  MotherYear.mdev + Psingle15.mdev  + Foreigners.mdev + SoMigration.mdev +IncomePer.mdev +  City_Village.mdev +  Pediatrics.mdev
                      + (1|ken), data = dsethib1, REML = FALSE)
summary(bwefffctmodel)
vif(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")

fixef(bwefffctmodel)

#検定
options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))


#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsethib1$rate ~ dsethib1$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsethib1$rate), col = "red3", lwd = 2)



result.hib1 <- data.frame(dsethib1$number,dsethib1$name, dsethib1$ken,dsethib1$rate,
                        residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.hib1, file="C:/Users/Yuki/Documents/R/Mthesis/result.hib1.csv", sep=",")



