#hib2

library(car)
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")


dsethib2 <- read_excel("dsethib2.xlsx")
summary(dsethib2)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsethib2)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsethib2, REML = FALSE)
summary(anovamodel)


#CWC 
dsethib2$Psingle15.m <-ave(dsethib2$Psingle15, dsethib2$ken)
dsethib2$IncomePer.m <-ave(dsethib2$IncomePer, dsethib2$ken)
dsethib2$Chi_Fam15.m <-ave(dsethib2$Chi_Fam15, dsethib2$ken)

dsethib2$Psingle15.cwc <- dsethib2$Psingle15 - dsethib2$Psingle15.m
dsethib2$IncomePer.cwc <- dsethib2$IncomePer - dsethib2$IncomePer.m
dsethib2$Chi_Fam15.cwc <- dsethib2$Chi_Fam15 - dsethib2$Chi_Fam15.m

#mdev

Psingle15.mdev <- dsethib2$Psingle15.m - mean(dsethib2$Psingle15.m)
IncomePer.mdev <- dsethib2$IncomePer.m - mean(dsethib2$IncomePer.m)
Chi_Fam15.mdev <- dsethib2$Chi_Fam15.m - mean(dsethib2$Chi_Fam15.m)


#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~ Chi_Fam15.cwc +  Psingle15.cwc + IncomePer.cwc
                       + Chi_Fam15.mdev + Psingle15.mdev + IncomePer.mdev 
                      + (1|ken), data = dsethib2, REML = FALSE)

summary(bwefffctmodel)
vif(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")

#要約

options(scipen=7)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
AIC(mrg1, mrg2, anovamodel,bwefffctmodel)
BIC(mrg1, mrg2, anovamodel,bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)



#残差プロット
plot(predict(bwefffctmodel), residuals(rancovamodel), xlim = c(88, 98), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(88, 98), ylim = c(-20, 20))


#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsethib2$rate ~ dsethib2$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsethib2$rate), col = "red3", lwd = 2)


result.hib2 <- data.frame(dsethib2$number,dsethib2$name, dsethib2$ken,dsethib2$rate,
                        residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.hib2, file="C:/Users/Yuki/Documents/R/Mthesis/result.hib2.csv", sep=",")


