#hib3

library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsethib3 <- read_excel("dsethib3.xlsx")
summary(dsethib3)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsethib3)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsethib3, REML = FALSE)
summary(anovamodel)


#CWC 
dsethib3$Psingle15.m <- ave(dsethib3$Psingle15, dsethib3$ken)
dsethib3$Checkup3mth.m <- ave(dsethib3$Checkup3mth, dsethib3$ken)
dsethib3$Chi_Fam15.m <- ave(dsethib3$Chi_Fam15, dsethib3$ken)
dsethib3$IncomePer.m <- ave(dsethib3$IncomePer, dsethib3$ken)

dsethib3$Psingle15.cwc <- dsethib3$Psingle15 - dsethib3$Psingle15.m
dsethib3$Checkup3mth.cwc <- dsethib3$Checkup3mth - dsethib3$Checkup3mth.m
dsethib3$Chi_Fam15.cwc <- dsethib3$Chi_Fam15 - dsethib3$Chi_Fam15.m
dsethib3$IncomePer.cwc <- dsethib3$IncomePer - dsethib3$IncomePer.m

#mdev

Psingle15.mdev <- dsethib3$Psingle15.m - mean(dsethib3$Psingle15.m)
Checkup3mth.mdev <- dsethib3$Checkup3mth.m - mean(dsethib3$Checkup3mth.m)
Chi_Fam15.mdev <- dsethib3$Chi_Fam15.m - mean(dsethib3$Chi_Fam15.m)
IncomePer.mdev <- dsethib3$IncomePer.m - mean(dsethib3$IncomePer.m)


bwefffctmodel <- lmer(rate ~  Chi_Fam15.cwc + Psingle15.cwc + Checkup3mth.cwc  + IncomePer.cwc
                      + Chi_Fam15.mdev + Psingle15.mdev + Checkup3mth.mdev  + IncomePer.mdev
                      + (1|ken), data = dsethib3, REML = FALSE)
summary(bwefffctmodel)
fixef(bwefffctmodel)
vif(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")

options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
BIC(mrg1, mrg2, anovamodel, bwefffctmodel)
AIC(mrg1, mrg2, anovamodel, bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsethib3$rate ~ dsethib3$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsethib3$rate), col = "red3", lwd = 2)

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(88, 98), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(88, 98), ylim = c(-20, 20))


result.hib3 <- data.frame(dsethib3$number,dsethib3$name, dsethib3$ken,dsethib3$rate,
                        residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.hib3, file="C:/Users/Yuki/Documents/R/Mthesis/result.hib3.csv", sep=",")



