#hib4

library(readxl)
library(lmerTest)
library(car)
library(MuMIn)
options(na.action = "na.fail")

dsethib4 <- read_excel("dsethib4.xlsx")
summary(dsethib4)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup18m + Foreigners
           + NurseryRate + SoMigration + + IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsethib4)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)


#ANOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsethib4, REML = FALSE)
summary(anovamodel)



#CWC 
dsethib4$Checkup18m.m <- ave(dsethib4$Checkup18m, dsethib4$ken)
dsethib4$Psingle15.m <- ave(dsethib4$Psingle15, dsethib4$ken)
dsethib4$IncomePer.m <- ave(dsethib4$IncomePer, dsethib4$ken)
dsethib4$Chi_Fam15.m <- ave(dsethib4$Chi_Fam15, dsethib4$ken)
dsethib4$Workers.m <- ave(dsethib4$Workers, dsethib4$ken)
dsethib4$Foreigners.m <- ave(dsethib4$Foreigners, dsethib4$ken)

dsethib4$Checkup18m.cwc <- dsethib4$Checkup18m - dsethib4$Checkup18m.m
dsethib4$Psingle15.cwc <- dsethib4$Psingle15 - dsethib4$Psingle15.m
dsethib4$IncomePer.cwc <- dsethib4$IncomePer - dsethib4$IncomePer.m
dsethib4$Chi_Fam15.cwc <- dsethib4$Chi_Fam15 - dsethib4$Chi_Fam15.m
dsethib4$Workers.cwc <- dsethib4$Workers - dsethib4$Workers.m
dsethib4$Foreigners.cwc <- dsethib4$Foreigners - dsethib4$Foreigners.m

#mdev

Psingle15.mdev <- dsethib4$Psingle15.m - mean(dsethib4$Psingle15.m)
IncomePer.mdev <- dsethib4$IncomePer.m - mean(dsethib4$IncomePer.m)
Checkup18m.mdev <- dsethib4$Checkup18m.m - mean(dsethib4$Checkup18m.m)
Chi_Fam15.mdev <- dsethib4$Chi_Fam15.m - mean(dsethib4$Chi_Fam15.m)
Foreigners.mdev <- dsethib4$Foreigners.m - mean(dsethib4$Foreigners.m)
Workers.mdev <- dsethib4$Workers.m - mean(dsethib4$Workers.m)

maomodel <-  lmer(rate ~  Chi_Fam15.mdev + Psingle15.mdev + Checkup18m.mdev +  Foreigners.mdev + IncomePer.mdev +
                  + Workers.mdev + (1|ken), data = dsethib4, REML = FALSE)
summary(maomodel)



#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~   Chi_Fam15.cwc  + Psingle15.cwc + Checkup18m.cwc + Foreigners.cwc + IncomePer.cwc +Workers.cwc 
                      + Chi_Fam15.mdev + Psingle15.mdev + Checkup18m.mdev +  Foreigners.mdev + IncomePer.mdev  + Workers.mdev 
                      + (1|ken), data = dsethib4, REML = FALSE)
summary(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")

fixef(bwefffctmodel)

options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
BIC(mrg1, mrg2, anovamodel, bwefffctmodel)
AIC(mrg1, mrg2, anovamodel, bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)



#残差プロット
plot(predict(rancovamodel), residuals(rancovamodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))


#箱ひげ図
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsethib4$rate ~ dsethib4$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsethib4$rate), col = "red3", lwd = 2)


result.hib4 <- data.frame(dsethib4$number,dsethib4$name, dsethib4$ken,dsethib4$rate,
                          residuals(mrg2), residuals(bwefffctmodel),scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.hib4, file="C:/Users/Yuki/Documents/R/Mthesis/result.hib4.csv", sep=",")



