#pne1
library(readxl)
library(lmerTest)
library(car)
library(MuMIn)
options(na.action = "na.fail")

dsetpne1 <- read_excel("dsetpne1.xlsx")
summary(dsetpne1)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics,  data = dsetpne1)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)


#ANOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetpne1, REML = FALSE)
summary(anovamodel)
#random effects ICC = (ken/Residual + ken = 0.0666559)


#model4 CWC 
dsetpne1$MotherYear.m <- ave(dsetpne1$MotherYear, dsetpne1$ken)
dsetpne1$Chi_Fam15.m <- ave(dsetpne1$Chi_Fam15, dsetpne1$ken)
dsetpne1$Psingle15.m <- ave(dsetpne1$Psingle15, dsetpne1$ken)
dsetpne1$Foreigners.m <- ave(dsetpne1$Foreigners, dsetpne1$ken)
dsetpne1$SoMigration.m <-ave(dsetpne1$SoMigration, dsetpne1$ken)
dsetpne1$IncomePer.m <- ave(dsetpne1$IncomePer, dsetpne1$ken)
dsetpne1$City_Village.m <- ave(dsetpne1$City_Village, dsetpne1$ken)
dsetpne1$Pediatrics.m <- ave(dsetpne1$Pediatrics, dsetpne1$ken)

dsetpne1$Psingle15.cwc <- dsetpne1$Psingle15 - dsetpne1$Psingle15.m
dsetpne1$IncomePer.cwc <- dsetpne1$IncomePer - dsetpne1$IncomePer.m
dsetpne1$City_Village.cwc <- dsetpne1$City_Village - dsetpne1$City_Village.m
dsetpne1$Chi_Fam15.cwc <- dsetpne1$Chi_Fam15 - dsetpne1$Chi_Fam15.m
dsetpne1$Pediatrics.cwc <- dsetpne1$Pediatrics - dsetpne1$Pediatrics.m
dsetpne1$Foreigners.cwc <- dsetpne1$Foreigners - dsetpne1$Foreigners.m
dsetpne1$MotherYear.cwc <- dsetpne1$MotherYear - dsetpne1$MotherYear.m
dsetpne1$SoMigration.cwc <- dsetpne1$SoMigration - dsetpne1$SoMigration.m

#mdev

Psingle15.mdev <- dsetpne1$Psingle15.m - mean(dsetpne1$Psingle15.m)
City_Village.mdev <- dsetpne1$City_Village.m - mean(dsetpne1$City_Village.m)
IncomePer.mdev <- dsetpne1$IncomePer.m - mean(dsetpne1$IncomePer.m)
Chi_Fam15.mdev <- dsetpne1$Chi_Fam15.m - mean(dsetpne1$Chi_Fam15.m)
Foreigners.mdev <- dsetpne1$Foreigners.m - mean(dsetpne1$Foreigners.m)
Pediatrics.mdev <- dsetpne1$Pediatrics.m - mean(dsetpne1$Pediatrics.m)
MotherYear.mdev <- dsetpne1$MotherYear.m - mean(dsetpne1$MotherYear.m)
SoMigration.mdev <- dsetpne1$SoMigration.m - mean(dsetpne1$SoMigration.m)

#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  MotherYear.cwc + Chi_Fam15.cwc  + Psingle15.cwc + Foreigners.cwc  +  SoMigration.cwc  + IncomePer.cwc+ City_Village.cwc +  Pediatrics.cwc  
                      + MotherYear.mdev + Chi_Fam15.mdev  + Psingle15.mdev + Foreigners.mdev  +  SoMigration.mdev  + IncomePer.mdev+ City_Village.mdev +  Pediatrics.mdev
                      + (1|ken), data = dsetpne1, REML = FALSE)
summary(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")
vif(bwefffctmodel)
fixef(bwefffctmodel)

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))

#boxplot
library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetpne1$rate ~ dsetpne1$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47),ylim = c(70, 120), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetpne1$rate), col = "red3", lwd = 2)

#summary
options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
BIC(mrg1, mrg2, anovamodel, bwefffctmodel)
AIC(mrg1, mrg2, anovamodel, bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


result.pne1 <- data.frame(dsetpne1$number,dsetpne1$name, dsetpne1$ken,dsetpne1$rate,
                          residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))




write.table(result.pne1, file="C:/Users/Yuki/Documents/R/Mthesis/result.pne1.csv", sep=",")