#pne2
library(readxl)
library(lmerTest)
library(car)
library(MuMIn)
options(na.action = "na.fail")

dsetpne2 <- read_excel("dsetpne2.xlsx")
summary(dsetpne2)

mrg1 <- lm(rate ~ MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetpne2)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)
confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANCOVA  
anovamodel <- lmer(rate ~  (1|ken), data = dsetpne2, REML = FALSE)
summary(anovamodel)


#CWC 
dsetpne2$Psingle15.m <-ave(dsetpne2$Psingle15, dsetpne2$ken)
dsetpne2$IncomePer.m <-ave(dsetpne2$IncomePer, dsetpne2$ken)
dsetpne2$Chi_Fam15.m <-ave(dsetpne2$Chi_Fam15, dsetpne2$ken)

dsetpne2$Psingle15.cwc <- dsetpne2$Psingle15 - dsetpne2$Psingle15.m
dsetpne2$IncomePer.cwc <- dsetpne2$IncomePer - dsetpne2$IncomePer.m
dsetpne2$Chi_Fam15.cwc <- dsetpne2$Chi_Fam15 - dsetpne2$Chi_Fam15.m


#mdev

Psingle15.mdev <- dsetpne2$Psingle15.m - mean(dsetpne2$Psingle15.m)
IncomePer.mdev <- dsetpne2$IncomePer.m - mean(dsetpne2$IncomePer.m)
Chi_Fam15.mdev <- dsetpne2$Chi_Fam15.m - mean(dsetpne2$Chi_Fam15.m)

bwefffctmodel <- lmer(rate ~ Chi_Fam15.cwc +  Psingle15.cwc + IncomePer.cwc
                      + Chi_Fam15.mdev +  Psingle15.mdev + IncomePer.mdev 
                      + (1|ken), data = dsetpne2, REML = FALSE)

summary(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")

#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))

library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetpne2$rate ~ dsetpne2$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetpne2$rate), col = "red3", lwd = 2)


options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
BIC(mrg1, mrg2, anovamodel, bwefffctmodel)
AIC(mrg1, mrg2, anovamodel, bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


result.pne2 <- data.frame(dsetpne2$number,dsetpne2$name, dsetpne2$ken,dsetpne2$rate,
                        residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.pne2, file="C:/Users/Yuki/Documents/R/Mthesis/result.pne2.csv", sep=",")



