#pne2
library(readxl)
library(lmerTest)
library(MuMIn)
options(na.action = "na.fail")

dsetpne3 <- read_excel("dsetpne3.xlsx")
summary(dsetpne3)


mrg1 <- lm(rate ~MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup3mth + Foreigners 
           + NurseryRate + SoMigration +IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetpne3)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANCOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetpne3, REML = FALSE)
summary(anovamodel)


#CWC 
dsetpne3$Psingle15.m <- ave(dsetpne3$Psingle15, dsetpne3$ken)
dsetpne3$IncomePer.m <- ave(dsetpne3$IncomePer, dsetpne3$ken)
dsetpne3$Chi_Fam15.m <- ave(dsetpne3$Chi_Fam15, dsetpne3$ken)
dsetpne3$MassVac.m <- ave(dsetpne3$MassVac, dsetpne3$ken)

dsetpne3$Psingle15.cwc <- dsetpne3$Psingle15 - dsetpne3$Psingle15.m
dsetpne3$IncomePer.cwc <- dsetpne3$IncomePer - dsetpne3$IncomePer.m
dsetpne3$Chi_Fam15.cwc <- dsetpne3$Chi_Fam15 - dsetpne3$Chi_Fam15.m
dsetpne3$MassVac.cwc <- dsetpne3$MassVac - dsetpne3$MassVac.m

#mdev

Psingle15.mdev <- dsetpne3$Psingle15.m - mean(dsetpne3$Psingle15.m)
IncomePer.mdev <- dsetpne3$IncomePer.m - mean(dsetpne3$IncomePer.m)
Chi_Fam15.mdev <- dsetpne3$Chi_Fam15.m - mean(dsetpne3$Chi_Fam15.m)
MassVac.mdev <- dsetpne3$MassVac.m - mean(dsetpne3$MassVac.m)



#集団・個人レベル効果モデル

bwefffctmodel <- lmer(rate ~  Psingle15.cwc + IncomePer.cwc  +Chi_Fam15.cwc + MassVac.cwc 
                      + Psingle15.mdev + IncomePer.mdev + Chi_Fam15.mdev + MassVac.mdev
                      + (1|ken), data = dsetpne3, REML = FALSE)
summary(bwefffctmodel)
confint(bwefffctmodel, level = .95, method = "Wald")
fixef(bwefffctmodel)


#残差プロット
plot(predict(bwefffctmodel), residuals(bwefffctmodel), xlim = c(90, 100), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(90, 100), ylim = c(-20, 20))


library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetpne3$rate ~ dsetpne3$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetpne3$rate), col = "red3", lwd = 2)



options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bwefffctmodel)
BIC(mrg1, mrg2, anovamodel, bwefffctmodel)
AIC(mrg1, mrg2, anovamodel, bwefffctmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bwefffctmodel)


result.pne3 <- data.frame(dsetpne3$number,dsetpne3$name, dsetpne3$ken,dsetpne3$rate,
                          residuals(mrg2), residuals(bwefffctmodel), scale(residuals(mrg2)), scale(residuals(bwefffctmodel)))

write.table(result.pne3, file="C:/Users/Yuki/Documents/R/Mthesis/result.pne3.csv", sep=",")



#標準化 