#pne4

library(readxl)
library(lmerTest)
library(car)
library(MuMIn)
options(na.action = "na.fail")
  
dsetpne4 <- read_excel("dsetpne4.xlsx")
summary(dsetpne4)


mrg1 <- lm(rate ~MotherYear +Chi_Fam15 + Psingle15 + PWork15 + Checkup18m + Foreigners
           + NurseryRate + SoMigration + + IncomePer + City_Village + Workers + MassVac + Pediatrics, data = dsetpne4)

mrg2 <- step(mrg1)

summary(mrg1)
summary(mrg2)

confint(mrg1, level = .95, method = "Wald")
coef(mrg1)

confint(mrg2, level = .95, method = "Wald")
coef(mrg2)



#ANOVA nullmodel 
anovamodel <- lmer(rate ~  (1|ken), data = dsetpne4, REML = FALSE)
summary(anovamodel)

#CWC 
dsetpne4$Chi_Fam15.m <- ave(dsetpne4$Chi_Fam15, dsetpne4$ken)
dsetpne4$Psingle15.m <- ave(dsetpne4$Psingle15, dsetpne4$ken)
dsetpne4$Checkup18m.m <- ave(dsetpne4$Checkup18m, dsetpne4$ken)
dsetpne4$IncomePer.m <- ave(dsetpne4$IncomePer, dsetpne4$ken)
dsetpne4$Pediatrics.m <- ave(dsetpne4$Pediatrics, dsetpne4$ken)

dsetpne4$Psingle15.cwc <- dsetpne4$Psingle15 - dsetpne4$Psingle15.m
dsetpne4$Checkup18m.cwc <- dsetpne4$Checkup18m - dsetpne4$Checkup18m.m
dsetpne4$IncomePer.cwc <- dsetpne4$IncomePer - dsetpne4$IncomePer.m
dsetpne4$Chi_Fam15.cwc <- dsetpne4$Chi_Fam15 - dsetpne4$Chi_Fam15.m
dsetpne4$Pediatrics.cwc <- dsetpne4$Pediatrics - dsetpne4$Pediatrics.m


#mdev
Chi_Fam15.mdev <- dsetpne4$Chi_Fam15.m - mean(dsetpne4$Chi_Fam15.m)
Psingle15.mdev <- dsetpne4$Psingle15.m - mean(dsetpne4$Psingle15.m)
Checkup18m.mdev <- dsetpne4$Checkup18m.m - mean(dsetpne4$Checkup18m.m)
IncomePer.mdev <- dsetpne4$IncomePer.m - mean(dsetpne4$IncomePer.m)
Pediatrics.mdev <- dsetpne4$Pediatrics.m - mean(dsetpne4$Pediatrics.m)


bweffectmodel <- lmer(rate ~   Chi_Fam15.cwc + Psingle15.cwc + Checkup18m.cwc + +IncomePer.cwc +  Pediatrics.cwc
                      +Chi_Fam15.mdev +  Psingle15.mdev + Checkup18m.mdev +IncomePer.mdev + + Pediatrics.mdev
                      + (1|ken), data = dsetpne4, REML = FALSE)
summary(bweffectmodel)
fixef(bweffectmodel)
confint(bweffectmodel, level = .95, method = "Wald")

#残差プロット
plot(predict(rancovamodel), residuals(rancovamodel), xlim = c(88, 98), ylim = c(-20, 20))
plot(predict(mrg2), residuals(mrg2),  xlim = c(88, 98), ylim = c(-20, 20))


library(RColorBrewer)
display.brewer.all()
cols = brewer.pal(2, "Pastel1") 
kname <- c("北海道",  "青森県", "岩手県", "宮城県", "秋田県", "山形県",  "福島県", "茨城県", "栃木県",
           "群馬県","埼玉県",  "千葉県", "東京都", "神奈川県" ,"新潟県", "富山県", "石川県", "福井県",
           "山梨県", "長野県", "岐阜県", "静岡県", "愛知県", "三重県", "滋賀県", "京都府", "大阪府", 
           "兵庫県", "奈良県", "和歌山県", "鳥取県", "島根県", "岡山県", "広島県", "山口県", "徳島県", 
           "香川県", "愛媛県", "高知県", "福岡県", "佐賀県", "長崎県", "熊本県", "大分県", "宮崎県",
           "鹿児島県", "沖縄県")
my_color1 <- adjustcolor(cols[2], alpha=0.4)

bplot1 <- boxplot(dsetpne4$rate ~ dsetpne4$ken, names = kname, col = my_color1, border= "cyan4",xlim = c(1, 47), 
                  xlab = "", ylab = "接種率" , las = 3, cex.axis=0.8, cex.lab=0.8) 
par(new=TRUE) 
abline(h = mean(dsetpne4$rate), col = "red3", lwd = 2)


options(scipen=10)
summary(mrg1)
summary(mrg2)
summary(anovamodel)
summary(bweffectmodel)
BIC(mrg1, mrg2, anovamodel, bweffectmodel)
AIC(mrg1, mrg2, anovamodel, bweffectmodel)
r.squaredGLMM(anovamodel)
r.squaredGLMM(bweffectmodel)


result.pne4 <- data.frame(dsetpne4$number,dsetpne4$name, dsetpne4$ken,dsetpne4$rate,
                        residuals(mrg2), residuals(bweffectmodel),scale(residuals(mrg2)), scale(residuals(bweffectmodel)))

write.table(result.pne4, file="C:/Users/Yuki/Documents/R/Mthesis/result.pne4.csv", sep=",")


